/*************************************************************************************

1. Prior to running this code, users should do as follows:

	1)  Download Lobbying Data and Campaig Finance Data from https://www.opensecrets.org/bulk-data/downloads before running this code.
		Lobbying Data includes 7 tables. Among them, we use 3 tables: agency, issue, and lobbying.
		Campaign Finance Data from Open Secret dataset consist of 5 tables: candidates, FEC committees, individual contributions, PAC to candidates, and PAC to PACs.
		Users should change all pipes (|) to quotation marks (") and save in the "src" folder before importing.	

	2)  As of 10/11/2020, a file downloaded from the website on the contributions from PACs to PACs in 2008 (pac_others08.txt) is incomplete. 
		We use the correct file (pac_others08_CRP.txt) that we received from the Center for Responsive Politics (Open Secret) upon our request.
		Useres should not delete this "pac_others08_CRP.txt" file in the "src" folder.
	
	3)  Users should install a STATA package spmap (ssc install spmap) since we use spmap to generate maps.

	4)	Users should change the path of the master folder (line 79).


2. For detailed comments and explanations, please refer to each do file.


3. This master code generates three excel files and two maps in the "out" folder:

	1) "lobbying_firm_focused.xlsx" - Lobbying by big-6 BMS producers (not limited to BMS-related issue);
		- The "issue_added" sheet includes all described issues in disclosures.
		- The "collapsed" sheet includes the lobbied amount that can be used to aggregate.
		- The "recipients" sheet shows all agencies lobbying expenditures were spent.

	2) "lobbying_bms_focused.xlsx" - BMS-related lobbying expenditure;
		- The "issue_added" sheet includes all described issues in disclosures.
		- The "collapsed" sheet includes the lobbied amount that can be used to aggregate.
		- The "recipients" sheet shows all agencies lobbying expenditures were spent.

	3) "political_contributions.xlsx" - political contributions from Big-6 BMS producers and their parents;
		- The "data" sheet includes quarterly contributions by Big-6 disaggregated by several categories.
		- Variable explanation:
		Group		: the relevant infant formula manufacturers of the contribution.
		pac=0		: the contribution is made by an employee of the manufacturer.
		pac=1		: the contribution is made by a PAC of the manufacturer.
		cand=0		: the contribution goes to another PAC including political parties.
		cand=1		: the contribution directly goes to a candidate.
		election=HR	: the contribution goes to a candidate for the House of Representative.
		election=SE	: the contribution goes to a candidate for the Senate.
		election=PR	: the contribution goes to a candidate for the President.
		RecipCode	: A two-character code defining the type of recipient. 
					  For candidates, the first character is party (“D” for Democratic, “R” for Republican, “3” for Independent, Libertarian or third party, “U” for Unknown.) 
					  The second character is “W” for Winner, “L” for Loser, “I” for incumbent, “C” for Challenger, “O” for “Open Seat”, and “N” for Non-incumbent. 
					  Incumbent, Challenger and Open Seat are based on CRPICO. “N” is reserved for candidates that are neither in office nor running during the cycle in question.
					  For party committees, the first character is party and the second character is “P.” For PACs, the first character is “P” and for outside spending groups, "O". 
					  For both, the second character is “B” for Business, “L” for Labor”, “I” for Ideological, “O” for “Other” and “U” for unknown.
					  Party extracts the first character from RecipCode.
					  Status extracts the second character from RecipCode.
		- The "to all by donor" sheet shows the political contributions by each of Big-6.
		- The "to candidates by party" sheet shows the political contributions by Big-6 offered to candidates, disaggregated by party.
		- The "to candidates by election" sheet shows the political contributions to candidates by election.
		- The "to candidates by election" sheet shows the political contributions to candidates by the result of the election (winner, loser, others)
		
	4) "bf_rate.eps" - percentage of children breastfed at 12 months, by country;

	5) "code_status.eps" - country implementation status of the International Code, 2018.


************************************************************************************/

clear
set more off
cap log close
macro drop _all
scalar drop _all
set scheme s1color
graph set window fontface arial

************* SETTING DIRECTORIES (change the path) **********************************************
*	Users should change the path of the master folder.
*	There are five subfolders in the master folder: src, dta, out, log
*	src: import raw data from this folder
*	dta: dta files generated during the process are stored in this folder
*	out: finalized excel files and image files are stored in this folder
*	log: log files are stored in this folder
**************************************************************************************************

gl folder "C:\Users\Manho\OneDrive - University of California, Davis\Econ\RA_RUSS_Substitutes\Regime complex replication package"	// Define working directory
gl mapdata "$folder\src\world_2017_database" // world map data
gl mapcoor "$folder\src\world_2017_coords" // world map coordinates

cd "$folder"


*** 1. Lobbying expenditure
do "$folder/do/lobbying.do"


*** 2. Political contributions
do "$folder/do/contribution.do"


*** 3. Maps (breastfeeding rates, implementation status of the International Code)
do "$folder/do/maps.do"
